@@ -10,20 +10,20 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.4.13"
+#define MARIADB_CLIENT_VERSION_STR	"10.4.15"
 #define MARIADB_BASE_VERSION		"mariadb-10.4"
-#define MARIADB_VERSION_ID		100413
+#define MARIADB_VERSION_ID		100415
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100413
-#define MYSQL_SERVER_VERSION            "10.4.13-MariaDB"
+#define MYSQL_VERSION_ID                100415
+#define MYSQL_SERVER_VERSION            "10.4.15-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.8"
-#define MARIADB_PACKAGE_VERSION_ID 30108
+#define MARIADB_PACKAGE_VERSION "3.1.9"
+#define MARIADB_PACKAGE_VERSION_ID 30109
 #define MARIADB_SYSTEM_TYPE "OpenBSD"
-#define MARIADB_MACHINE_TYPE "sparc64"
+#define MARIADB_MACHINE_TYPE "amd64"
 #define MARIADB_PLUGINDIR "/usr/local/lib/mysql/plugin"
 
 /* mysqld compile time options */
